Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/mono.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'mcs/class/PresentationFramework/Test/ObjectWriter.cs')
-rw-r--r--mcs/class/PresentationFramework/Test/ObjectWriter.cs7
1 files changed, 4 insertions, 3 deletions
diff --git a/mcs/class/PresentationFramework/Test/ObjectWriter.cs b/mcs/class/PresentationFramework/Test/ObjectWriter.cs
index 73618b8c251..887ae575d4f 100644
--- a/mcs/class/PresentationFramework/Test/ObjectWriter.cs
+++ b/mcs/class/PresentationFramework/Test/ObjectWriter.cs
@@ -1,5 +1,5 @@
//
// ObjectWriter.cs - NUnit Test Cases for the xaml object builder
//
// Author:
// Iain McCoy (iain@mccoy.id.au)
@@ -37,13 +37,14 @@ using System.Reflection;
using System.Windows;
using System.CodeDom.Compiler;
using Mono.Windows.Serialization;
+using System.Windows.Serialization;
using Xaml.TestVocab.Console;
namespace MonoTests.System.Windows.Serialization
{
[TestFixture]
-public class ObjectWriterTest {
+public class ParserTest {
string code;
[SetUp]
@@ -179,7 +180,7 @@ public class ObjectWriterTest {
private void compare(object expected)
{
string mapping = "<?Mapping ClrNamespace=\"Xaml.TestVocab.Console\" Assembly=\"./TestVocab.dll\" XmlNamespace=\"console\" ?>\n";
- object o = ObjectWriter.Parse(new XmlTextReader(new StringReader(mapping + code)));
+ object o = Parser.LoadXml(new XmlTextReader(new StringReader(mapping + code)));
Assert.AreEqual(expected, o);
}
@@ -1,5 +1,5 @@
//
-// ObjectWriter.cs - NUnit Test Cases for the xaml object builder
+// Parser.cs - NUnit Test Cases for the xaml object builder
//
// Author: